@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 
 rm -rfv __pycache__
-rm -rfv i18n
+rm -rfv data/i18n
 rm -rfv locale
 rm -v data/po/*/*.old
\ No newline at end of file
