@@ -1,17 +1,38 @@
 // Which page?
 current_page = document.location.href.match(/[^\/]+$/)[0];
 
+// Show an error dialog when JavaScript errors occur.
+$(window).on("error", function(evt) {
+    // Gets JavaScript Event
+    var e = evt.originalEvent;
+    friendly_txt = "Oops! Welcome encountered an internal error.\n\nPlease tell the Ubuntu MATE Developers so this can fixed right away.";
+    if (e.message) {
+        alert(friendly_txt + "\n\nError:\n\t" + e.message + "\nLine:\n\t" + e.lineno + "\nFile:\n\t" + e.filename);
+    } else {
+        alert(friendly_txt + "\n\nError:\n\t" + e.type + "\nElement:\n\t" + (e.srcElement || e.target));
+    }
+});
+
+// Pass commands to Python
+function cmd(instruction) {
+  document.title = instruction;
+  setTimeout(function(){
+    document.title = 'null';
+  }, 10);
+}
+
 // Global across all pages
 $(window).load(function() {
     // Smoothly fade into the page.
-    $('.entire-page-fade').fadeIn('medium');
+    $('.entire-page-fade').jAnimate('pageIn');
+    $('.entire-page-fade').show();
     $('#navigation-right').hide();
     $('#navigation-right').fadeIn('medium');
 });
 
 // Smoothly fade out of the page.
 function smoothPageFade(target_href) {
-    $('.entire-page-fade').fadeOut('medium');
+    $('.entire-page-fade').jAnimate('pageOut');
     $('#navigation-title').fadeOut('medium');
     $('#navigation-right').fadeOut('medium');
     $('.navigation-button').fadeOut('medium');
@@ -20,32 +41,38 @@ function smoothPageFade(target_href) {
     }, 400);
 }
 
+// Back to the top function
+function backToTop() {
+    $("#content").animate({
+        scrollTop: 0
+    }, 600);
+    $('#scroll-top').addClass('active');
+    return false;
+};
+
 // When page first opens
 $(document).ready(function() {
   // Animate navigation elements on page load
-  if ( current_page != 'software-only.html' ) {
-    $('#menu-button').jAnimateOnce('fadeInLeft');
-    $('#navigation-title').jAnimateOnce('fadeInDown');
+  if ( current_page != 'splash-boutique.html' ) {
+    if ( current_page != 'software.html') {
+      $('#menu-button').show();
+      $('#menu-button').jAnimateOnce('pageIn');
+      $('#navigation-title').show();
+      $('#navigation-title').jAnimateOnce('pageIn');
+    }
   }
 
-  // Back to the top
-  $(window).scroll(function () {
+  // Show back to top button on page scroll
+  $('#content').scroll(function () {
       if ($(this).scrollTop() > 90) {
           $('#scroll-top').fadeIn();
+          $('#scroll-top-always-show').removeClass('disabled');
       } else {
           $('#scroll-top').fadeOut();
+          $('#scroll-top').removeClass('active');
+          $('#scroll-top-always-show').addClass('disabled');
       }
   });
-
-  $('#navigation-right').append('<a id="scroll-top" class="navigation-button" style="display:none"><span class="fa fa-chevron-up"></span></a>')
-
-  $('#scroll-top').click(function () {
-      $("html, body").animate({
-          scrollTop: 0
-      }, 600);
-      return false;
-  });
-
 });
 
 // Smoothly fade between two elements (by ID)
@@ -57,19 +84,20 @@ function smoothFade(from, to) {
 // Smoothly fade the navigation sub-title
 function changeSubtitle(textToDisplay) {
   // Smoothly fade subtitle
-  $('#navigation-sub-title').fadeOut();
+  $('#navigation-sub-title').fadeOut('fast');
   setTimeout(function() {
     $('#navigation-sub-title').html(textToDisplay);
-    $('#navigation-sub-title').fadeIn();
-  }, 400);
+    $('#navigation-sub-title').fadeIn('fast');
+  }, 200);
 }
 
 // For pages that depend on an internet connection, but Welcome couldn't connect.
-function reconnectTimeout() {
+function reconnectRetry() {
+  cmd('checkInternetConnection');
   if ( ! $('#reconnectFailed').is(':visible') ) {
     $('#reconnectFailed').fadeIn();
   } else {
-    $('#reconnectFailed').jAnimateOnce('pulse');
+    $('#reconnectFailed').jAnimateOnce('flash');
   }
 }
 
@@ -86,21 +114,27 @@ function setCursorNormal() {
   $('a').removeClass('cursor-wait');
 }
 
+// Keyboard shortcuts
+$('body').bind('keypress', function(e) {
+	if ( e.keyCode == 27 ) {  // ESC
+    if ( current_page != "index.html" ) {
+      smoothPageFade("index.html")
+    }
+	}
+});
+
 ///////////////////////////////////////////////////////////////
 
 // Main Menu Only = Animation
 if ( current_page == 'index.html' ) {
 
   // Animate elements of the page
-  $('#main-menu-logo').jAnimateOnce('rotateIn');
-  $('.main-menu-text').fadeIn('slow');
-  $('#open-at-start').jAnimateOnce('fadeIn');
-  setTimeout(function(){
-    $('#mate-blur').jAnimateOnce('zoomIn');
-    $('#mate-blur').show();
-  }, 50);
+  $('.main-menu-text').fadeIn('medium');
+  $('#mate-blur').jAnimateOnce('zoomIn');
+  $('#mate-blur').show();
 
   function exitMenu(target) {
+      $("#open-at-start").fadeOut();
       // Show a "wait" cursor for the Software page, as there is a slight delay.
       if ( target == 'software.html' ) {
           setCursorBusy()
@@ -110,21 +144,6 @@ if ( current_page == 'index.html' ) {
       smoothPageFade(target)
   }
 
-  // Have we greeted the user already?
-  if ( document.cookie == 'greeted=yes' ) {
-
-    $(document).ready(function () {
-      $(".fade").removeClass("fade");
-      $(".fade-1s").removeClass("fade-1s");
-      $(".fade-2s").removeClass("fade-2s");
-      $(".fade-3s").removeClass("fade-3s");
-      $(".fade-4s").removeClass("fade-4s");
-      $(".fade-5s").removeClass("fade-5s");
-    });
-  }
-
-  document.cookie = 'greeted=yes';
-
   // Enable tooltips
   $(document).ready(function() {
     $("body").tooltip({ selector: '[data-toggle=tooltip]' });
@@ -164,185 +183,60 @@ if ( current_page == 'index.html' ) {
       $('#main-menu-logo').jAnimateOnce('zoomIn');
     }, 91000);
 
-    // Internally work with days, months and years as a number.
-    function dateAsNumber(day, month, year) {
-      // Assumes 'month' parameter is in base 0.
-      // day, month   = Required.
-      // year         = Optional, set to 'null' to use current year.
-      var then = new Date();
-      if ( year != null ) {
-        then.setYear(year);
-      }
-      then.setMonth(month-1);
-      then.setDate(day);
-      var finalNumber = Math.floor( then / (1000 * 60 * 60 * 24) );
-      //~ var dateInYears = current + todayAsNumber;
-      //~ console.log('** finalNumber: '+finalNumber)
-      //~ return dateInYears;
-      return finalNumber;
-    }
-
-    // Activate Confetti
-    function activateConfetti() {
-      if ( disable_confetti == false ) {
-        $('#special').html('<canvas id="confetti" width="100%" height="100%" style="z-index: -1000; position: absolute; top: 0px; left: 0px;"></canvas>');
-        startConfetti();
-        return
-      } else {
-        return
-      }
-    }
-
-    // Use 'dd', 'mm' and 'yyyy' variables to re-use code.
-    var today = new Date();
-    var dd = 0;  var mm = 0;  var yyyy = 0; var release = '';
-
-    // What is today?
-    var today = new Date();
-    var todayAsNumber = dateAsNumber(today.getDate(), today.getMonth()+1, null)
-
-    // Check dates for special events.
-    function specialEventCheck(dateNo, title_text, show_confetti, fa_icon) {
-      // dateNo        = dateAsNumber(dd, mm, yyyy) function.
-      // title_text    = Text to display when date matches.
-      // show_confetti = True / False = Celebrate when date matches.
-      // fa_icon       = FontAwesome icon to display. Usually 'bell' or 'calendar' or 'bug'.
-      var do_show_this = false;
-      if ( dateNo == todayAsNumber) {
-        // Today is the day!
-        var do_show_this = true;
-      }
-      if ( do_show_this == true ) {
-        $('.main-menu-text').hide();
-        $('.main-menu-text').fadeIn();
-        $('.main-menu-text').html("<span class='fa fa-" + fa_icon + "'></span>&nbsp;" + title_text);
-        if ( show_confetti == true ) {
-          activateConfetti();
-        }
-      }
-    }
-
-    // Dates to be checking for.
-    function checkDates() {
-      // String variables are passed via Python. See _push_config for "Special Event Strings".
-
-      // Official Flavour Status - 26/Feb/2015
-      var age = today.getFullYear() - 2015;
-      dd = 26; mm = 02; yyyy = null;
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-7, flavour_anniversary_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-6, flavour_anniversary_future + ' ' + days_in + ' 6 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-5, flavour_anniversary_future + ' ' + days_in + ' 5 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-4, flavour_anniversary_future + ' ' + days_in + ' 4 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-3, flavour_anniversary_future + ' ' + days_in + ' 3 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-2, flavour_anniversary_future + ' ' + days_in + ' 2 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-1, flavour_anniversary_future + ' ' + tomorrow, true, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)  , flavour_anniversary_present + ' ' + age + ' ' + years_ago, true, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+1, flavour_anniversary_past + ' ' + yesterday, true, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+2, flavour_anniversary_past + ' 2 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+3, flavour_anniversary_past + ' 3 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+4, flavour_anniversary_past + ' 4 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+5, flavour_anniversary_past + ' 5 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+6, flavour_anniversary_past + ' 6 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+7, flavour_anniversary_past + ' 7 ' + days_ago, false, 'calendar');
-
-      // Project Birthday - 21/Jun/2014
-      var age = today.getFullYear() - 2014;
-      dd = 21; mm = 06; yyyy = null;
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-7, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-6, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + days_in + ' 6 ' + future_days, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-5, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + days_in + ' 5 ' + future_days, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-4, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + days_in + ' 4 ' + future_days, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-3, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + days_in + ' 3 ' + future_days, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-2, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + days_in + ' 2 ' + future_days, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-1, project_birthday_future + ' ' + age + ' ' + years_old + ' ' + tomorrow + ' ' + project_birthday, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)  , project_birthday_present + ' ' + age + ' ' + years_old + ' ' + today_string + ' ' + project_birthday, true, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+1, project_birthday_past + ' ' + age + ' ' + years_old + ' ' + yesterday + ' ' + project_birthday, true, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+2, project_birthday_past + ' ' + age + ' ' + years_old + ', 2 ' + days_ago, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+3, project_birthday_past + ' ' + age + ' ' + years_old + ', 3 ' + days_ago, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+4, project_birthday_past + ' ' + age + ' ' + years_old + ', 4 ' + days_ago, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+5, project_birthday_past + ' ' + age + ' ' + years_old + ', 5 ' + days_ago, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+6, project_birthday_past + ' ' + age + ' ' + years_old + ', 6 ' + days_ago, false, 'birthday-cake');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+7, project_birthday_past + ' ' + age + ' ' + years_old + ', 7 ' + days_ago, false, 'calendar');
-
-      // Holiday Celebrations
-      specialEventCheck(dateAsNumber(31,12,null), celebrate_new_year, true, 'calendar');
-      specialEventCheck(dateAsNumber(01,01,null), celebrate_new_year, true, 'calendar');
-
-      // 16.04 Beta 2
-      dd = 24; mm = 03; yyyy = 2016;
-      release = 'Ubuntu MATE 16.04 Beta 2';
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-3, release + ' ' + project_release_future + ' ' + days_in + ' 3 ' + future_days, false, 'bug');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-2, release + ' ' + project_release_future + ' ' + days_in + ' 2 ' + future_days, false, 'bug');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-1, release + ' ' + project_release_future + ' ' + tomorrow, false, 'bug');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)  , release + ' ' + project_release_present, true, 'bug');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+1, project_release_thanks + ' ' + release + '.', true, 'bug');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+2, project_release_thanks + ' ' + release + '.', false, 'bug');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+3, project_release_thanks + ' ' + release + '.', false, 'bug');
-
-      // 16.04 Final Release
-      dd = 21; mm = 04; yyyy = 2016;
-      release = 'Ubuntu MATE 16.04 LTS';
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-7, release + ' ' + project_release_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-6, release + ' ' + project_release_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-5, release + ' ' + project_release_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-4, release + ' ' + project_release_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-3, release + ' ' + project_release_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-2, release + ' ' + project_release_future + ' ' + days_in + ' 7 ' + future_days, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)-1, release + ' ' + project_release_future + ' ' + tomorrow, true, 'bell');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)  , release + ' ' + project_release_present, true, 'bell');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+1, release + ' ' + project_release_past + ' ' + yesterday, true, 'bell');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+2, release + ' ' + project_release_past + ' 2 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+3, release + ' ' + project_release_past + ' 3 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+4, release + ' ' + project_release_past + ' 4 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+5, release + ' ' + project_release_past + ' 5 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+6, release + ' ' + project_release_past + ' 6 ' + days_ago, false, 'calendar');
-      specialEventCheck(dateAsNumber(dd,mm,yyyy)+7, release + ' ' + project_release_past + ' 7 ' + days_ago, false, 'calendar');
-
-      // To-do as possible improvement: Retrieve events as a list from server.
-    }
 }
 
 
 // Introduction/Features = Animation
 if ( current_page == 'introduction.html' || current_page == 'features.html' ) {
   new WOW().init();
+  new WOW({
+    scrollContainer: '#content'
+  }).init();
 }
 
 
 // Software Page Only = Categories for Apps
 if ( current_page == 'software.html' ) {
 
+    // Do not show navigation elements
+    $('#menu-button').hide();
+    $('#navigation-title').hide();
+    $('#navigation-right').hide();
+
     // Initial variables.
-    var currentCategory;
+    var currentCategory = '#boutique-loading';
     var hideNonFree = false;
     var system_info = '';
 
-    // Show the first category.
-    currentCategory = '#Intro';
-    $(currentCategory).jAnimateOnce('zoomInLeft');
-    $(currentCategory).show();
-
     // Switch to another category.
-    function switchCategory(now, next, subtitle) {
+    function switchCategory(now, next, subtitle, hideCheckmarks=false) {
         // Smoothly fade subtitle
         changeSubtitle(subtitle);
-        $('html, body').animate({ scrollTop: 0 }, 0)
+        $('#content').animate({ scrollTop: 0 }, 500)
+
+        // Remove any other current page highlights
+        $('#navigation-queue').removeClass('active');
+        $('#navigation-search').removeClass('active');
+        $('#navigation-news').removeClass('active');
+        $('#navigation-prefs').removeClass('active');
 
         // Fade in non-free toggle as it starts hidden, except on the Misc. page,
         // where it's replaced by a command visibility toggle.
         if ( next == '#Misc' ) {
           smoothFade('#non-free-toggle','#show-misc-cmds');
+        } else if ( hideCheckmarks == true ) {
+          $('#non-free-toggle').fadeOut();
+          $('#show-misc-cmds').fadeOut();
         } else {
           smoothFade('#show-misc-cmds','#non-free-toggle');
         }
 
         // Animate out, then animate in next category.
-        $(now).fadeOut('fast');
+        $(now).fadeOut();
         setTimeout(function() {
           $(now).hide();
           currentCategory = next;
-          $(next).show();
-          $(next).jAnimateOnce('fadeInDown');
+          $(next).fadeIn();
         }, 250);
 
         // Show all apps again, in case the previous page was filtered.
@@ -369,7 +263,7 @@ if ( current_page == 'software.html' ) {
       // Python passes 'server_string' variable to allow translation.
       changeCategoryTab('#Servers', server_string);
       $('#ServersBtn').tab('show');
-      $('html, body').animate({ scrollTop: 0 }, 100)
+      $('#content').animate({ scrollTop: 0 }, 100)
 
       // WORKAROUND = Cannot use ' or " strings, use numbers to get target div ID:
       if ( appno == 1 ) {  targetDiv = 'minecraft-server';  }
@@ -377,7 +271,7 @@ if ( current_page == 'software.html' ) {
       if ( appno == 3 ) {  targetDiv = 'murmur';  }
 
       setTimeout(function(){
-          $('html, body').animate({
+          $('#content').animate({
               scrollTop: $('#'+targetDiv).offset().top - 100
           }, 1000);
       }, 1000);
@@ -387,12 +281,6 @@ if ( current_page == 'software.html' ) {
     $(document).ready(function() {
       $("body").tooltip({ selector: '[data-toggle=tooltip]' });
     });
-    $('[rel=freedominfo]').popover({
-        html : true,
-        content: function() {
-          return $('#popover_content_wrapper').html();
-        }
-    });
 
     // Filtering applications by subcategory and/or proprietary software.
     selected_filter = 'none';
@@ -402,23 +290,12 @@ if ( current_page == 'software.html' ) {
         applyFilter();
     });
 
-    $('#non-free-toggle').on('click', function (e) {
-        toggleNonFree();
-    });
-
     function applyFilter() {
-        window.location.href = 'cmd://filter-apps?' + selected_filter + '?';
+        cmd('filter-apps?' + selected_filter + '?');
     }
 
     function toggleNonFree() {
-        window.location.href = 'cmd://filter-apps?' + selected_filter + '?toggle';
-    }
-
-    // Featured Grid - Randomly populate and add applications to the grid.
-    var iconID = 0;
-    function addToGrid(icon) {
-      iconID++;
-      $('#featured-grid').append('<img src="img/applications/'+icon+'.png" id="appIcon' + iconID + '" class="grid-hidden" />');
+        cmd('filter-apps?' + selected_filter + '?toggle');
     }
 
     // Featured Grid - Set classes to create a semi-circle fade effect.
@@ -490,6 +367,59 @@ if ( current_page == 'software.html' ) {
     // Smooth transition for footer.
     $('#footer-left').hide();
     $('#footer-left').fadeIn();
+
+    // Toggling right navigation "tabs"
+    function resetNavTabs() {
+      $('#tabs li').removeClass('active');
+      $('#non-free-toggle').fadeOut();
+      $('#show-misc-cmds').fadeOut();
+    }
+
+    // Toggling to show the Boutique News
+    function showNews(subtitle) {
+      switchCategory(currentCategory, '#News', subtitle, true);
+      resetNavTabs();
+      $('#navigation-news').addClass('active');
+    }
+
+    // Toggling to show the Search Page
+    function showSearch(subtitle) {
+      switchCategory(currentCategory, '#Search', subtitle, true)
+      resetNavTabs();
+      $('#navigation-search').addClass('active');
+      $('#search-results').html('');
+      $('#search-results').hide();
+      $('#search-empty').hide();
+      $('#search-total').hide();
+      $('#search-terms').val('');
+    }
+
+    // Perform a search
+    function searchNow() {
+      keywords = $('#search-terms').val();
+      cmd('search?' + keywords)
+    }
+
+    // Search again but include non-free matches.
+    function searchAgainNonFree() {
+      toggleNonFree()
+      searchNow()
+    }
+
+    // Toggling to show the Preferences page
+    function showPrefs(subtitle) {
+      switchCategory(currentCategory, '#Preferences', subtitle, true)
+      resetNavTabs();
+      $('#navigation-prefs').addClass('active');
+    }
+
+    // Toggling to show the Queue page
+    function showQueue(subtitle) {
+      switchCategory(currentCategory, '#Queue', subtitle, true)
+      resetNavTabs();
+      $('#navigation-queue').addClass('active');
+    }
+
 }
 
 
@@ -499,41 +429,56 @@ if ( current_page == 'splash.html' ) {
   // Scenes - Delayed elements to appear
   $(document).ready(function()
   {
-    $('#sceneA').show();
-    $('#sceneA').jAnimateOnce('fadeIn');
-    $('#splash-multilingual').show();
-    $('#splash-multilingual').jAnimateOnce('zoomIn');
+    $('body').show();
+    $('#splash-logo').show();
+    $('#splash-logo').jAnimateOnce('entrance');
+    $('#MATE-Logo').show();
+    $('#MATE-Logo').jAnimateOnce('mateRoll');
 
-    setTimeout(function(){ $('#circle1').fadeOut('medium');}, 2000);
-    setTimeout(function(){ $('#circle2').fadeOut('medium');}, 2100);
-    setTimeout(function(){ $('#circle3').fadeOut('medium');}, 2200);
-    setTimeout(function(){ $('#circle4').fadeOut('medium');}, 2300);
-    setTimeout(function(){ $('#circle5').fadeOut('medium');}, 2400);
+    $('#MATE-Text1').css('opacity','0');
+    $('#MATE-Text2').css('opacity','0');
+    $('#MATE-Text1').show();
+    $('#MATE-Text2').show();
 
     setTimeout(function(){
-      $('#sceneA').show();
-      $('#sceneA').fadeOut();
-      $('#splash-multilingual').fadeOut('slow');
-    }, 2500);
+      $('#MATE-Text1').hide();
+      $('#MATE-Text1').css('opacity','');
+      $('#MATE-Text1').fadeIn(1500);
+    }, 250);
 
     setTimeout(function(){
-      $('#sceneB').show();
-      $('#sceneB').jAnimateOnce('zoomIn');
-      $('body').addClass('fade-to-menu');
+      $('#MATE-Text2').hide();
+      $('#MATE-Text2').css('opacity','');
+      $('#MATE-Text2').fadeIn(1500);
+    }, 600);
+
+    setTimeout(function(){
+      $('#header').show();
+      $('#footer').show();
+      $('#header').jAnimateOnce('fadeInDown');
+      $('#footer').jAnimateOnce('fadeInUp');
+    }, 2000);
+
+    setTimeout(function(){
+      $('#splash-logo').hide();
+      $('#skip-splash').fadeOut();
+      if ( quick_splash == true ) {
+        $('#white-start').fadeOut('fast');
+        continueToPage(false)
+      } else {
+        $('#splash-welcome').show();
+        $('#splash-welcome').jAnimateOnce('zoomInInverse');
+        $('#white-start').fadeOut('slow');
+      }
     }, 3000);
 
     setTimeout(function(){
-      $('body').removeClass('fade-to-menu');
-      $('body').css('background-color','#f4f4f4');
-    }, 4000);
-
-    setTimeout(function(){
-      $('#sceneB').fadeOut();
-    }, 5000);
+      $('#splash-welcome').fadeOut();
+    }, 4500);
 
     setTimeout(function(){
       continueToPage(false)
-    }, 5300);
+    }, 5000);
 
   });
 
@@ -542,69 +487,111 @@ if ( current_page == 'splash.html' ) {
 
   function continueToPage(skipped) {
     if ( skipped == true ) {
-      $('body').addClass('fade-to-menu');
-      $('#sceneA').fadeOut('medium');
-      $('#sceneB').fadeOut('medium');
-      $('#splash-multilingual').fadeOut('medium');
+      $('#splash-logo').fadeOut('fast');
+      $('#white-start').fadeOut('fast');
+      $('#header').fadeIn('fast');
+      $('#footer').fadeIn('fast');
       setTimeout(function(){
           smoothPageFade(splashNextPage + '.html');
-      }, 500);
+      }, 100);
     } else {
       smoothPageFade(splashNextPage + '.html');
     }
-
   }
+}
 
+
+// Splash for Entering Boutique
+if ( current_page == 'splash-boutique.html' ) {
+    setCursorBusy();
+    setTimeout(function() {
+      $('#boutique-splash').jAnimate('zoomOutInverse');
+    }, 1000);
+
+    $('#Text1').css('opacity','0');
+    $('#Text2').css('opacity','0');
+    $('#Text1').show();
+    $('#Text2').show();
+
+    setTimeout(function(){
+      $('#Text1').hide();
+      $('#Text1').css('opacity','');
+      $('#Text1').fadeIn(750);
+    }, 100);
+
+    setTimeout(function(){
+      $('#Text2').hide();
+      $('#Text2').css('opacity','');
+      $('#Text2').fadeIn(750);
+    }, 200);
 }
 
 
 // Getting Started Only - Index Pane for Selecting Topics
 if ( current_page == 'gettingstarted.html' ) {
+  var nextPage = "initial";
+  var prevPage = "initial";
 
-  function indexOpen() {
-    // Is the index already open?
-    if ($('#index-menu').is(':visible')) {
-      indexClose();
-    } else {
-      // Open the Index
-      $('#index-open').addClass('disabled');
-      $('#index-open').prop('disabled', true);
-      $("#index-overlay").fadeIn();
-      $("#index-menu").show();
-      $('#index-menu').jAnimateOnce('fadeInLeft');
-    }
-  }
-
-  function indexClose() {
-    $('#index-open').removeClass('disabled');
-    $('#index-open').prop('disabled', false);
-    if ($('#index-menu').is(':visible')) {
-      $("#index-overlay").fadeOut();
-      $('#index-menu').jAnimateOnce('fadeOutLeft',function(){
-        $("#index-menu").hide();
-      });
-    }
-  }
-
-  function changePage(id,humanText) {
+  function changePage(id, do_not_update_btn_state) {
     // 'id' is one used for <div>.
-    // 'humanText' is displayed on navigation's sub title.
-    indexClose();
-    $('.topicContents').fadeOut();
-    $('#navigation-sub-title').fadeOut();
+    var id = '#' + id;
+    var title = $(id).data("title");
+    var icon  = $(id).data("icon");
+
+    if ( id == "#none" ) {
+      return
+    }
 
     // Smoothly fade between topics
+    $('.topicContents').fadeOut();
+    $('#current-topic').fadeOut();
+    $('#current-icon').fadeOut();
+
     setTimeout(function() {
-    $('#navigation-sub-title').html(humanText);
-    $('#navigation-sub-title').fadeIn();
-    $('#'+id).fadeIn();
+      $('#current-topic').html(title);
+      $('#current-topic').fadeIn();
+      $('#current-icon').fadeIn();
+      $(id).fadeIn();
+
+      $("#current-icon").removeClass();
+      $("#current-icon").addClass("fa").addClass(icon);
+
+      // Update prev/next button states
+      if ( do_not_update_btn_state == null ) {
+        prevPage = $(id).data("prev");
+        prevText = $('#'+prevPage).data("title");
+        nextPage = $(id).data("next");
+        nextText = $('#'+nextPage).data("title");
+
+        if ( prevPage == "none" ) {
+          $("#topic-prev").addClass("disabled");
+        } else {
+          $("#topic-prev").removeClass("disabled");
+        }
+
+        if ( nextPage == "none" ) {
+          $("#topic-next").addClass("disabled");
+        } else {
+          $("#topic-next").removeClass("disabled");
+        }
+
+        // Gather system specs if applicable.
+        if ( id == "#specs" ) {
+          InitSystemInfo();
+        }
+      }
     }, 500);
   }
 
-  // Show initial page and index pane on page load
-  changePage('initial','Choose a Topic');
-  setTimeout(function() { indexOpen(); }, 500);
-  $('#index-open').jAnimateOnce('fadeInDown');
+  // On page entry, animate the topic subheading.
+  $('#topic-subheading').show().jAnimateOnce('fadeInDown');
+  $("#topic-subheading").children().fadeIn('fast');
+
+  function exitPage() {
+    $("#topic-subheading").children().fadeOut('fast');
+    $('#topic-subheading').slideUp();
+    smoothPageFade('index.html');
+  }
 
   // Show additional information on the page based on checkbox state.
   $('.dualBootWin').hide();
@@ -649,24 +636,23 @@ if ( current_page == 'gettingstarted.html' ) {
   }, 1000);
 
   // Expand / Collapse sub-sections to keep it tidy.
-  function toggleSub(divID,arrowID) {
-    if ( $('#'+divID).is(":visible") ) {
-      $('#'+divID).fadeOut();
-      $('#'+arrowID).removeClass('fa-chevron-up');
-      $('#'+arrowID).addClass('fa-chevron-down');
-    } else {
-      $('#'+divID).fadeIn();
+  function toggleSub(divID, arrowID) {
+    $(".sub-collapse > h3 > span").addClass('fa-chevron-down').removeClass('fa-chevron-up');
+    alreadyOpen = $("#"+divID).is(":visible");
+    $(".drivers-section").slideUp("fast");
+    if ( alreadyOpen == false ) {
+      $("#"+divID).slideDown('fast');
       $('#'+arrowID).removeClass('fa-chevron-down');
       $('#'+arrowID).addClass('fa-chevron-up');
     }
   }
 
   // Fetch system specifications if not cached already.
-  // Wait a couple of seconds so it doesn't look like application had frozen.
   function InitSystemInfo() {
     setCursorBusy()
+    // Wait a second to allow a smooth fade animation.
     setTimeout(function() {
-      window.location.href = "cmd://init-system-info";
+      cmd("init-system-info");
     }, 1000);
   }
 
@@ -701,7 +687,7 @@ if ( current_page == 'donate.html' ) {
       // Add a Month = (New Column)
       function addMonth(m,y) {
         cellID = y + '-' + m;
-        $('#donationTable tr:last').append('<td id="' + cellID + '" style="text-align:center;"><a href="cmd://link?https://ubuntu-mate.org/blog/ubuntu-mate-' + numToMonth(m) + '-' + y + '-supporters/">' + numToShortMonth(m) + '</a></td>');
+        $('#donationTable tr:last').append('<td id="' + cellID + '" style="text-align:center;"><button class="link" onclick="cmd(\'link?https://ubuntu-mate.org/blog/ubuntu-mate-' + numToMonth(m) + '-' + y + '-supporters/\')">' + numToShortMonth(m) + '</button></td>');
       }
 
       // Add a Blank Month = (New Column, Empty)
@@ -870,9 +856,3 @@ if ( current_page == 'donate.html' ) {
 
 }
 
-
-// Entering Software Only Mode
-if ( current_page == 'software-only.html' ) {
-    setCursorBusy()
-}
-
